@@ -44,8 +44,8 @@ glmpcr.tune <- function(y, x, M = 10, maxk = 10, mat = NULL, ncores = 1, graph =
     for (vim in 1:M) {
       ytest <- y[mat[, vim] ]   ## test set dependent vars
       ytrain <- y[-mat[, vim] ]   ## train set dependent vars
-      xtrain <- x[-mat[, vim], ]   ## train set independent vars
-      xtest <- x[mat[, vim],, drop = FALSE ]  ## test set independent vars
+      xtrain <- x[-mat[, vim], , drop = FALSE]   ## train set independent vars
+      xtest <- x[mat[, vim], , drop = FALSE ]  ## test set independent vars
 	    vec <- prcomp(xtrain, center = FALSE)$rotation
       z <- xtrain %*% vec  ## PCA scores
 
@@ -75,11 +75,10 @@ glmpcr.tune <- function(y, x, M = 10, maxk = 10, mat = NULL, ncores = 1, graph =
     cl <- makePSOCKcluster(ncores)
     registerDoParallel(cl)
     er <- numeric(maxk)
-    msp <- foreach(vim = 1:M, .combine = rbind, .packages = "Rfast",
-                   .export = c("colVars", "colmeans") ) %dopar% {
+    msp <- foreach(vim = 1:M, .combine = rbind, .packages = "Rfast", .export = c("glm_logistic", "glm_poisson") ) %dopar% {
       ytest <- y[mat[, vim] ]  ## test set dependent vars
       ytrain <-  y[-mat[, vim] ]   ## train set dependent vars
-      xtrain <- x[-mat[, vim], ]   ## train set independent vars
+      xtrain <- x[-mat[, vim], , drop = FALSE]   ## train set independent vars
       xtest <- x[mat[, vim], , drop = FALSE]  ## test set independent vars
 	    vec <- prcomp(xtrain, center = FALSE)$rotation
       z <- xtrain %*% vec  ## PCA scores
@@ -109,7 +108,7 @@ glmpcr.tune <- function(y, x, M = 10, maxk = 10, mat = NULL, ncores = 1, graph =
   }
 
   mpd <- Rfast::colmeans(msp)
-  if ( graph )  plot(1:maxk, mpd, xlab = "Number of principal components", ylab = "Mean predicted deviance", type = "b")
+  if ( graph )  plot(1:maxk, mpd, xlab = "Number of principal components", ylab = "Mean predicted deviance", type = "b" ,cex.alb = 1.3)
 
   names(mpd) <- paste("PC", 1:maxk, sep = " ")
   performance <- min(mpd)
